pub struct AnnotationsEntrySetAction {
pub annotation_id: String,
pub entry: AnnotationEntry,
}Expand description
Upsert an {@link AnnotationEntry} within an existing annotation — adds a new entry, or replaces one identified by {@link AnnotationEntry.id}. The dispatching client assigns the {@link AnnotationEntry.id} of a new entry. If {@link annotationId} does not match any current annotation the action is a no-op.
Fields
annotation_id: StringThe {@link Annotation.id} the entry belongs to.
entry: AnnotationEntryThe new or replacement entry.