pub struct ChatPendingMessageRemovedAction {
pub kind: PendingMessageKind,
pub id: String,
}Expand description
A pending message was removed (steering or queued).
Dispatched by clients to cancel a pending message, or by the server when it consumes a message (e.g. starting a turn from a queued message or injecting a steering message into the current turn).
Fields
kind: PendingMessageKindWhether this is a steering or queued message
id: StringIdentifier of the pending message to remove