ChatQueuedMessagesReorderedAction

Struct ChatQueuedMessagesReorderedAction 

pub struct ChatQueuedMessagesReorderedAction {
    pub order: Vec<String>,
}
Reorder the queued messages.

The order array contains the IDs of queued messages in their new desired order. IDs not present in the current queue are ignored. Queued messages whose IDs are absent from order are appended at the end in their original relative order (so a client with a stale view of the queue never silently drops messages).

Fields

order: Vec<String>

Queued message IDs in the desired order