pub struct ChatToolCallStartAction {
pub turn_id: String,
pub tool_call_id: String,
pub meta: Option<JsonObject>,
pub tool_name: String,
pub display_name: String,
pub intention: Option<String>,
pub contributor: Option<ToolCallContributor>,
}Expand description
A tool call begins — parameters are streaming from the LM.
The server sets {@link ToolCallContributor | contributor} to identify
the origin of the tool. For client-provided tools, the named client is
responsible for executing the tool once it reaches the running state
and dispatching chat/toolCallComplete. For MCP-served tools, the
server executes the call against the named McpServerCustomization.
Fields
turn_id: StringTurn identifier
tool_call_id: StringTool call identifier
meta: Option<JsonObject>Additional provider-specific metadata for this tool call.
Clients MAY look for well-known keys here to provide enhanced UI.
For example, a ptyTerminal key with { input: string; output: string }
indicates the tool operated on a terminal (both input and output may
contain escape sequences).
tool_name: StringInternal tool name (for debugging/logging)
display_name: StringHuman-readable tool name
intention: Option<String>Human-readable description of what the tool invocation intends to do
contributor: Option<ToolCallContributor>Reference to the contributor of the tool being called. Absent for server-side tools that are not contributed by a client or MCP server.