pub struct ChatTruncatedAction {
pub turn_id: Option<String>,
}Expand description
Truncates a session’s history. If turnId is provided, all turns after that
turn are removed and the specified turn is kept. If turnId is omitted, all
turns are removed.
If there is an active turn it is silently dropped and the chat status
returns to idle.
Common use-case: truncate old data then dispatch a new
chat/turnStarted with an edited message.
Fields
turn_id: Option<String>Keep turns up to and including this turn. Omit to clear all turns.