pub struct RootConfigChangedAction {
pub config: JsonObject,
pub replace: Option<bool>,
}Expand description
Fired when agent-host configuration values change.
By default, the reducer merges the new values into state.config.values.
Set replace to true to replace all values instead of merging.
Fields
config: JsonObjectUpdated config values
replace: Option<bool>When true, replaces all config values instead of merging