pub struct SessionCustomizationRemovedAction {
pub id: String,
}Expand description
Removes a customization by id.
Searches every container and its children for the entry. If the entry is a container, its children are removed with it. Is a no-op when no matching id is found.
Fields
id: StringThe id of the customization to remove.