pub struct SessionIsReadChangedAction {
pub is_read: bool,
}Expand description
The read state of the session changed.
Dispatched by a client to mark a session as read (e.g. after viewing it) or unread (e.g. after new activity since the client last looked at it).
Fields
is_read: boolWhether the session has been read