pub struct SessionPendingMessageSetAction {
pub kind: PendingMessageKind,
pub id: String,
pub message: Message,
}Expand description
A pending message was set (upsert semantics: creates or replaces).
For steering messages, this always replaces the single steering message.
For queued messages, if a message with the given id already exists it is
updated in place; otherwise it is appended to the queue. If the session is
idle when a queued message is set, the server SHOULD immediately consume it
and start a new turn.
A client is only allowed to send {@link MessageKind.User} messages.
Fields
kind: PendingMessageKindWhether this is a steering or queued message
id: StringUnique identifier for this pending message
message: MessageThe message content