pub struct TerminalCommandDetectionAvailableAction {}Expand description
Shell integration has loaded and the terminal now supports command detection. The server dispatches this when shell integration becomes available (which may happen asynchronously after the terminal is created).
Clients MUST NOT assume command detection is available until this action
(or terminal/commandExecuted) has been received.