pub struct TerminalCommandFinishedAction {
pub command_id: String,
pub exit_code: Option<i64>,
pub duration_ms: Option<i64>,
}Expand description
A command has finished executing.
The sequence of terminal/data actions between the preceding
terminal/commandExecuted (same commandId) and this action constitutes
the complete output of the command.
Fields
command_id: StringMatches the commandId from the corresponding commandExecuted
exit_code: Option<i64>Shell exit code. undefined if the shell did not report one.
duration_ms: Option<i64>Wall-clock duration of the command in milliseconds, as measured by the shell integration script on the server side.