pub struct TerminalResizedAction {
pub cols: i64,
pub rows: i64,
}Expand description
Terminal dimensions changed.
Dispatchable by clients to request a resize, or by the server to inform clients of the actual terminal dimensions.
Fields
cols: i64Terminal width in columns
rows: i64Terminal height in rows