pub enum AuthRequiredReason {
Required,
Expired,
}Expand description
Reason why authentication is required.
Variants
Required
The client has not yet authenticated for the resource
Expired
A previously valid token has expired or been revoked