pub enum MessageAttachmentKind {
Simple,
EmbeddedResource,
Resource,
Annotations,
}Expand description
Discriminant for {@link MessageAttachment} variants.
Variants
Simple
A simple, opaque attachment whose representation is described by the producer.
EmbeddedResource
An attachment whose data is embedded inline as a base64 string.
Resource
An attachment that references a resource by URI.
Annotations
An attachment that references annotations on an annotations channel.