pub struct ChangesSummary {
pub additions: Option<i64>,
pub deletions: Option<i64>,
pub files: Option<i64>,
}Expand description
Aggregate counts describing the file changes associated with a session.
All fields are optional so servers can populate only the metrics they cheaply have available.
Fields
additions: Option<i64>Total number of inserted lines across all changed files.
deletions: Option<i64>Total number of deleted lines across all changed files.
files: Option<i64>Number of files that have changes.