pub struct ChatInputTextQuestion {
pub id: String,
pub title: Option<String>,
pub message: String,
pub required: Option<bool>,
pub format: Option<String>,
pub min: Option<i64>,
pub max: Option<i64>,
pub default_value: Option<String>,
}Expand description
Text question within a chat input request.
Fields
id: StringStable question identifier used as the key in answers
title: Option<String>Short display title
message: StringPrompt shown to the user
required: Option<bool>Whether the user must answer this question to accept the request
format: Option<String>Format hint for text questions, such as email, uri, date, or date-time
min: Option<i64>Minimum string length
max: Option<i64>Maximum string length
default_value: Option<String>Default text