pub struct PendingMessage {
pub id: String,
pub message: Message,
}Expand description
A message queued for future delivery to the agent.
Steering messages are injected into the current turn mid-flight. Queued messages are automatically started as new turns after the current turn naturally finishes.
Fields
id: StringUnique identifier for this pending message
message: MessageThe message that will start the next turn