pub struct RootConfigState {
pub schema: ConfigSchema,
pub values: JsonObject,
}Expand description
Live agent-host configuration metadata.
The schema describes the available configuration properties and the values contain the current value for each resolved property.
Fields
schema: ConfigSchemaJSON Schema describing available configuration properties
values: JsonObjectCurrent configuration values