pub struct SessionConfigState {
pub schema: SessionConfigSchema,
pub values: JsonObject,
}Expand description
Live session configuration metadata.
The schema describes the available configuration properties and the values contain the current value for each resolved property.
Fields
schema: SessionConfigSchemaJSON Schema describing available configuration properties
values: JsonObjectCurrent configuration values