pub struct SessionInputNumberQuestion {
pub id: String,
pub title: Option<String>,
pub message: String,
pub required: Option<bool>,
pub min: Option<f64>,
pub max: Option<f64>,
pub default_value: Option<f64>,
}Expand description
Numeric question within a session input request.
Fields
id: StringStable question identifier used as the key in answers
title: Option<String>Short display title
message: StringPrompt shown to the user
required: Option<bool>Whether the user must answer this question to accept the request
min: Option<f64>Minimum value
max: Option<f64>Maximum value
default_value: Option<f64>Default numeric value