pub struct TextSelection {
pub range: TextRange,
}Expand description
A selection within a textual resource.
This is only meaningful for textual resources. Binary resources may still use resource or embedded resource attachments, but they should not use this text selection field.
Fields
range: TextRangeThe range covered by the selection.