pub struct ToolCallCancelledState {
pub tool_call_id: String,
pub tool_name: String,
pub display_name: String,
pub intention: Option<String>,
pub contributor: Option<ToolCallContributor>,
pub meta: Option<JsonObject>,
pub invocation_message: StringOrMarkdown,
pub tool_input: Option<String>,
pub reason: ToolCallCancellationReason,
pub reason_message: Option<StringOrMarkdown>,
pub user_suggestion: Option<Message>,
pub selected_option: Option<ConfirmationOption>,
}Expand description
Tool call was cancelled before execution.
Fields
tool_call_id: StringUnique tool call identifier
tool_name: StringInternal tool name (for debugging/logging)
display_name: StringHuman-readable tool name
intention: Option<String>Human-readable description of what the tool invocation intends to do
contributor: Option<ToolCallContributor>Reference to the contributor of the tool being called.
meta: Option<JsonObject>Additional provider-specific metadata for this tool call.
This MAY include a ui field corresponding to the MCP Apps (SEP-1865)
McpUiToolMeta found in MCP tool calls, which may be used in combination
with the {@link contributor} to serve MCP Apps.
invocation_message: StringOrMarkdownMessage describing what the tool will do
tool_input: Option<String>Raw tool input
reason: ToolCallCancellationReasonWhy the tool was cancelled
reason_message: Option<StringOrMarkdown>Optional message explaining the cancellation
user_suggestion: Option<Message>What the user suggested doing instead
selected_option: Option<ConfirmationOption>The confirmation option the user selected, if confirmation options were provided