pub struct ToolCallClientContributor {
pub client_id: String,
}Fields
client_id: StringIf this tool is provided by a client, the clientId of the owning client.
Absent for server-side tools.
When set, the identified client is responsible for executing the tool and
dispatching chat/toolCallComplete with the result.