pub struct ToolCallPendingResultConfirmationState {Show 15 fields
pub tool_call_id: String,
pub tool_name: String,
pub display_name: String,
pub intention: Option<String>,
pub contributor: Option<ToolCallContributor>,
pub meta: Option<JsonObject>,
pub invocation_message: StringOrMarkdown,
pub tool_input: Option<String>,
pub success: bool,
pub past_tense_message: StringOrMarkdown,
pub content: Option<Vec<ToolResultContent>>,
pub structured_content: Option<JsonObject>,
pub error: Option<AnyValue>,
pub confirmed: ToolCallConfirmationReason,
pub selected_option: Option<ConfirmationOption>,
}Expand description
Tool finished executing, waiting for client to approve the result.
Fields
tool_call_id: StringUnique tool call identifier
tool_name: StringInternal tool name (for debugging/logging)
display_name: StringHuman-readable tool name
intention: Option<String>Human-readable description of what the tool invocation intends to do
contributor: Option<ToolCallContributor>Reference to the contributor of the tool being called.
meta: Option<JsonObject>Additional provider-specific metadata for this tool call.
This MAY include a ui field corresponding to the MCP Apps (SEP-1865)
McpUiToolMeta found in MCP tool calls, which may be used in combination
with the {@link contributor} to serve MCP Apps.
invocation_message: StringOrMarkdownMessage describing what the tool will do
tool_input: Option<String>Raw tool input
success: boolWhether the tool succeeded
past_tense_message: StringOrMarkdownPast-tense description of what the tool did
content: Option<Vec<ToolResultContent>>Unstructured result content blocks.
This mirrors the content field of MCP CallToolResult.
structured_content: Option<JsonObject>Optional structured result object.
This mirrors the structuredContent field of MCP CallToolResult.
error: Option<AnyValue>Error details if the tool failed
confirmed: ToolCallConfirmationReasonHow the tool was confirmed for execution
selected_option: Option<ConfirmationOption>The confirmation option the user selected, if confirmation options were provided