pub struct ToolCallStreamingState {
pub tool_call_id: String,
pub tool_name: String,
pub display_name: String,
pub contributor: Option<ToolCallContributor>,
pub meta: Option<JsonObject>,
pub partial_input: Option<String>,
pub invocation_message: Option<StringOrMarkdown>,
}Expand description
LM is streaming the tool call parameters.
Fields
tool_call_id: StringUnique tool call identifier
tool_name: StringInternal tool name (for debugging/logging)
display_name: StringHuman-readable tool name
contributor: Option<ToolCallContributor>Reference to the contributor of the tool being called.
meta: Option<JsonObject>Additional provider-specific metadata for this tool call.
This MAY include a ui field corresponding to the MCP Apps (SEP-1865)
McpUiToolMeta found in MCP tool calls, which may be used in combination
with the {@link contributor} to serve MCP Apps.
partial_input: Option<String>Partial parameters accumulated so far
invocation_message: Option<StringOrMarkdown>Progress message shown while parameters are streaming