pub struct SessionActiveClientChangedAction {
pub active_client: Option<SessionActiveClient>,
}Expand description
The active client for this session has changed.
A client dispatches this action with its own SessionActiveClient to claim
the active role, or with null to release it. The server SHOULD reject if
another client is already active. The server SHOULD automatically dispatch
this action with activeClient: null when the active client disconnects.
Fields
active_client: Option<SessionActiveClient>The new active client, or null to unset