pub struct ResourceRequestParams {
pub channel: Uri,
pub uri: Uri,
pub read: Option<bool>,
pub write: Option<bool>,
}Expand description
Requests permission to access a resource on the receiver’s filesystem.
resourceRequest is symmetrical and MAY be sent in either direction: a
client asks the server to grant access to a server-side resource, or a
server asks the client to grant access to a client-side resource. The
receiver decides whether to allow, deny, or prompt the user for the
requested access.
If the receiver denies access, it MUST respond with PermissionDenied
(-32009). The error data MAY include a ResourceRequestParams value
describing the access the caller would need to be granted for the
operation to succeed; see PermissionDeniedErrorData in
types/errors.ts.
After a successful resourceRequest, the caller MAY use the corresponding
resource* commands (e.g. resourceRead, resourceWrite) to perform the
operation. Receivers MAY rescind access at any time by returning
PermissionDenied on subsequent operations.
Either read, write, or both SHOULD be set to true. A request with
neither flag set is treated as read: true by receivers.
Fields
channel: UriChannel URI this command targets.
uri: UriResource URI being requested. Typically a file: URI on the receiver’s
filesystem, but any URI scheme that the receiver mediates access to is
allowed.
read: Option<bool>Whether the caller needs read access to the resource.
write: Option<bool>Whether the caller needs write access to the resource.