SessionSummary

Struct SessionSummary 

pub struct SessionSummary {
    pub resource: Uri,
    pub provider: String,
    pub title: String,
    pub status: u32,
    pub activity: Option<String>,
    pub created_at: i64,
    pub modified_at: i64,
    pub project: Option<ProjectInfo>,
    pub model: Option<ModelSelection>,
    pub agent: Option<AgentSelection>,
    pub working_directory: Option<Uri>,
    pub changes: Option<ChangesSummary>,
}

Fields

resource: Uri

Session URI

provider: String

Agent provider ID

title: String

Session title

status: u32

Current session status

activity: Option<String>

Human-readable description of what the session is currently doing

created_at: i64

Creation timestamp

modified_at: i64

Last modification timestamp

project: Option<ProjectInfo>

Server-owned project for this session

model: Option<ModelSelection>

Currently selected model

agent: Option<AgentSelection>

Currently selected custom agent.

Absent (undefined) means no custom agent is selected for this session — the session uses the provider’s default behavior.

working_directory: Option<Uri>

The working directory URI for this session

changes: Option<ChangesSummary>

Aggregate summary of file changes associated with this session. Servers may populate this to give clients a quick at-a-glance view of the session’s footprint (e.g., for list rendering) without requiring the client to subscribe to a changeset.